<!-- These are examples of badges you might want to add to your README:
     please update the URLs accordingly

[![Built Status](https://api.cirrus-ci.com/github/<USER>/rat-trig.svg?branch=main)](https://cirrus-ci.com/github/<USER>/rat-trig)
[![ReadTheDocs](https://readthedocs.org/projects/rat-trig/badge/?version=latest)](https://rat-trig.readthedocs.io/en/stable/)
[![Coveralls](https://img.shields.io/coveralls/github/<USER>/rat-trig/main.svg)](https://coveralls.io/r/<USER>/rat-trig)
[![PyPI-Server](https://img.shields.io/pypi/v/rat-trig.svg)](https://pypi.org/project/rat-trig/)
[![Conda-Forge](https://img.shields.io/conda/vn/conda-forge/rat-trig.svg)](https://anaconda.org/conda-forge/rat-trig)
[![Monthly Downloads](https://pepy.tech/badge/rat-trig/month)](https://pepy.tech/project/rat-trig)
[![Twitter](https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter)](https://twitter.com/rat-trig)
-->

[![Project generated with PyScaffold](https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold)](https://pyscaffold.org/)
[![Documentation Status](https://readthedocs.org/projects/rat-trig/badge/?version=latest)](https://rat-trig.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/luk036/rat-trig/badge.svg?branch=main)](https://coveralls.io/github/luk036/rat-trig?branch=main)

# 📐 rat-trig

> Rational Trigonometry

A longer description of your project goes here...

<!-- pyscaffold-notes -->

## 👉 Note

This project has been set up using PyScaffold 4.5. For details and usage
information on PyScaffold see https://pyscaffold.org/.
